@@ -6,10 +6,10 @@ class TestCase(test.TransactionTestCase):
 
     def _pre_setup(self):
         cache.cache.clear()
-        super(TestCase, self)._pre_setup()
+        super()._pre_setup()
 
 
-class ReplicationRouter(object):
+class ReplicationRouter:
     """Router for simulating an environment with DB replication
 
     This router directs all DB reads to a completely different database than
